ImageEncoderPort

Trait ImageEncoderPort 

pub trait ImageEncoderPort: Send + Sync {
    // Required method
    fn encode(
        &self,
        frame: &dyn MatView,
        kind: EncodingKind,
    ) -> Result<Vec<u8>, ImageEncodingError>;
}
Encodes a MatView into a byte buffer in one of the EncodingKinds.

Required Methods

fn encode( &self, frame: &dyn MatView, kind: EncodingKind, ) -> Result<Vec<u8>, ImageEncodingError>

Encode frame using kind and return the resulting bytes.

Implementors